# Workflow for generating Views controllde vocabularies

Unless otherwise noted, the location of files mentioned here are in this directory.

1. If creating terms for a new organism group, add the group to `part_collections.csv`.
2. Add any new subjectPart values for the group to `subjectPart/subjectPart_cv.csv`. Don't add any that already exist as analogs from other groups.
3. Create the links between the organism group to all of the parts (new or existing) in the top section of `part_collection_join.csv`.
4. If there are any new subjectOrientation values (unlikely at this point), add them to `subjectOrientation/subjectOrientation_cv.csv`.
5. For each new part added in 2 above, create links from the part to each orientation appropriate for that part in the lower section of `part_collection_join.csv`. NOTE: if a part in a certain organism group has different possible orientations from the same part in other organism groups, then that part can't be considered to be the same and a new part specific to that group should be created!
6. The two files with the basic part and orientation data need to be uploaded to the `rs.tdwg.org` repo on the TDWG GitHub site. For provisional changes, this should be done using a branch. If it's a ratified change, that branch can eventually be merged to the main (master) branch after testing. To make it easier to see what the new information is that's being added, we've been storing the changed files in subdirectories of `process/ac-revisions/` using the naming pattern `ac-views-cv-yyyy-mm-dd`. NOTE: the files placed in this directory should only have the rows for terms that are being **changed** from what they were before (modified or new). Rows for existing terms that are unmodified should **not** be included. This may require deleting some rows if the changes were made in steps 2 and 4 by adding to the existing rows.
7. When the script is run to update the data in the `rs.tdwg.org` repo, it needs information from a `config.json` file to tell it where the source files are and some other information. There is a separate one for each vocab to be updated, so I've been keeping versions `config_orient.json` and `config_part.json` as a record, and then copying them to the `process` directory and changing their name as I ran the script to regenerate each vocabulary.
8. Prior to running the processing script, copy the appropriate config file from 7 into the `process` directory and change its name to `config.json`. Note for 2022-04-19 update: The `namespace.csv` and `x-column-mappings.csv` files had to be modified to use the new `sawsdlrdf:modelReference` property.
9. Run the Python script `process.py` in the `process` directory of the `rs.tdwg.org` repo. Check the git diffs to make sure everything looks good, then push the changes. Change the `config.json` to the other vocabulary and repeat. If everything is good, push the changes.
10. Run the Python Jupyter notebook `build-page-orient.ipynb` in the subjectOrientation directory. It outputs the file as `index.md` but apparently for temporary purposes it's been called `subjectOrientation.md` in the `subjectOrientation` folder, so change the name to that.
11. Run the Python Jupyter notebook `build-page-part.ipynb` in the subjectPart directory as above. Push the changes to GitHub so they are visible.
12. Edit the `config.json` file in the `code` directory to the appropriate directory to pull data from `rs.tdwg.org` (e.g. `acorient`). Also set the value for `selection = 'part'` in the "Build the SKOS collections" part of the script. Run the Python Jupyter notebook `build-views-json-ld.ipynb` to generate the new JSON-LD for the terms, collections, as well as the collection Markdown documents. Repeat for the directory of the other vocab, then push the changes.

---
Revised 2022-04-19
