# subjectPart Controlled Vocabulary

**Title:** subjectPart Controlled Vocabulary

**Namespace URI:** http://rs.tdwg.org/acpart/values/

**Preferred namespace abbreviation:** acpart:

**Date version issued:** put ratification date here

**Date created:** put ratification date here

**Part of TDWG Standard:** http://www.tdwg.org/standards/638

**This version:** http://rs.tdwg.org/ac/doc/part/iso-date-here

**Latest version:** http://rs.tdwg.org/ac/doc/part/

**Abstract:** The Audubon Core term `subjectPart` describes the part of an organism morphology, behaviour, environment depicted in a media item or region of interest. The subjectPart Controlled Vocabulary provides terms that should be used as values for `ac:subjectPart` and its literal-valued analog `ac:subjectPartLiteral`. 

**Contributors:** Steven J. Baskauf (Vanderbilt University Libraries), Neil S. Cobb (Merriam-Powell Center for Environmental Research, Northern Arizona University), Jennifer C. Girón Duque (Natural Science Research Laboratory, Museum of Texas Tech University), Matthew Nielsen (Stockholm University), Mervin E. Pérez (University of Puerto Rico), Randy Singer (University of Michigan)

**Creator:** TDWG Views Controlled Vocabularies Task Group

**Bibliographic citation:** Views Controlled Vocabularies Task Group. 2022. subjectPart Controlled Vocabulary. Biodiversity Information Standards (TDWG). <http://rs.tdwg.org/ac/doc/part/>


## 1 Introduction (informative)

This document includes terms intended to be used as controlled values for the Audubon Core terms `ac:subjectPart` and `ac:subjectPartLiteral`. A [JSON-LD representation](https://tdwg.github.io/rs.tdwg.org/cvJson/acpart.json) of this SKOS Concept Scheme is available.

### 1.1 Status of the content of this document

Section 1 is informative (non-normative).

Section 2 is normative except as noted.

Section 3 is informative.

In Section 4, the values of the `Term IRI`, `Definition`, and `Controlled value` are normative. The value of `Usage` (if it exists for a given term) is normative.  The value of `Has broader concept` is normative. The values of `Term Name` are non-normative, although one can expect that the namespace abbreviation prefix is one commonly used for the term namespace.  `Label` and the values of all other properties (such as `Notes`) are non-normative.

### 1.2 RFC 2119 key words
The key words "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL NOT", "SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and "OPTIONAL" in this document are to be interpreted as described in [RFC 2119](https://tools.ietf.org/html/rfc2119).

## 2 Use of Terms

### 2.1 Relationship of value types to property terms

In accordance with the [Audubon Core Term List](http://rs.tdwg.org/ac/doc/termlist/) document, unabbreviated term IRIs MUST be used as values of the property `ac:subjectPart`. Controlled value strings SHOULD be used as values of the property `ac:subjectPartLiteral`.

### 2.2 Relationships with other concept schemes and collections (informative)

Particular `ac:subjectOrientation` values are appropriate for some `ac:subjectPart` values. The relationships between concepts in these two schemes are described by a [JSON-LD serialized SKOS Collection for each subject part](https://tdwg.github.io/rs.tdwg.org/cvJson/acorient_collection.json) that designates which subject orientations are appropriate for that part. Similarly, [JSON-LD serialized SKOS Collections have been established for some organism groups](https://tdwg.github.io/rs.tdwg.org/cvJson/acpart_collection.json) to indicate which subject parts exist for members of those groups. These collections are provided to aid application developers in filtering the concepts that should be presented to users and they may also be used for validation.

Neither of these Collections are normative and they are maintained outside of the Audubon Core standards framework in order to make their development agile.

## 3 Term index


[abdomen](#acpart_p0015) |
[antenna](#acpart_p0018) |
[antheridiophore](#acpart_p0033) |
[antheridium](#acpart_p0034) |
[archegoniophore](#acpart_p0032) |
[archegonium](#acpart_p0035) |
[bark](#acpart_p0002) |
[cranium](#acpart_p0028) |
[egg](#acpart_p0031) |
[entire organism](#acpart_p0001) |
[eye](#acpart_p0024) |
[female cone](#acpart_p0011) |
[fin](#acpart_p0030) |
[flower](#acpart_p0012) |
[foreleg](#acpart_p0021) |
[forewing](#acpart_p0019) |
[fruit](#acpart_p0008) |
[gemma cup](#acpart_p0036) |
[genitalia](#acpart_p0026) |
[head](#acpart_p0013) |
[hindleg](#acpart_p0023) |
[hindwing](#acpart_p0020) |
[inflorescence](#acpart_p0007) |
[leaf](#acpart_p0005) |
[leg](#acpart_p0016) |
[male cone](#acpart_p0010) |
[mandible](#acpart_p0029) |
[midleg](#acpart_p0022) |
[rhizome](#acpart_p0040) |
[seed](#acpart_p0009) |
[shell](#acpart_p0025) |
[skull](#acpart_p0027) |
[sori](#acpart_p0039) |
[sporophyte](#acpart_p0038) |
[stem](#acpart_p0004) |
[strobilis (cone)](#acpart_p0006) |
[subject part concept scheme](#acpart_p) |
[thallus](#acpart_p0037) |
[thorax](#acpart_p0014) |
[twig](#acpart_p0003) |
[unspecified part](#acpart_p0000) |
[wing](#acpart_p0017) 

## 4 Vocabulary
<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p"></a>Term Name  acpart:p</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p">http://rs.tdwg.org/acpart/values/p</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p-2022-01-01">http://rs.tdwg.org/acpart/values/version/p-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>subject part concept scheme</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>a SKOS concept scheme for ac:subjectOrientation</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>http://www.w3.org/2004/02/skos/core#ConceptScheme</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0000"></a>Term Name  acpart:p0000</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0000">http://rs.tdwg.org/acpart/values/p0000</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0000-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0000-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>unspecified part</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Part is not known because it is not specified</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>unspecifiedPart</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0001"></a>Term Name  acpart:p0001</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0001">http://rs.tdwg.org/acpart/values/p0001</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0001-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0001-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>entire organism</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>An entire multicellular organism</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/CARO_0000012">http://purl.obolibrary.org/obo/CARO_0000012</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>entireOrganism</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0002"></a>Term Name  acpart:p0002</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0002">http://rs.tdwg.org/acpart/values/p0002</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0002-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0002-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>bark</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant tissue outside the vascular cambium</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0004518">http://purl.obolibrary.org/obo/PO_0004518</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>bark</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0003"></a>Term Name  acpart:p0003</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0003">http://rs.tdwg.org/acpart/values/p0003</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0003-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0003-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>twig</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant shoot axis developed from axillary buds</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0025073">http://purl.obolibrary.org/obo/PO_0025073</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>twig</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0004"></a>Term Name  acpart:p0004</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0004">http://rs.tdwg.org/acpart/values/p0004</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0004-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0004-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>stem</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant shoot axis that is the primary axis as defined by</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0009047">http://purl.obolibrary.org/obo/PO_0009047</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>stem</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0005"></a>Term Name  acpart:p0005</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0005">http://rs.tdwg.org/acpart/values/p0005</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0005-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0005-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>leaf</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant non-reproductive phyllome</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0025034">http://purl.obolibrary.org/obo/PO_0025034</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>leaf</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0006"></a>Term Name  acpart:p0006</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0006">http://rs.tdwg.org/acpart/values/p0006</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0006-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0006-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>strobilis (cone)</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant reproductive system consisting of sporophylls</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0025083">http://purl.obolibrary.org/obo/PO_0025083</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>strobilis</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0007"></a>Term Name  acpart:p0007</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0007">http://rs.tdwg.org/acpart/values/p0007</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0007-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0007-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>inflorescence</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant reproductive shoot system containing flowers</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0009049">http://purl.obolibrary.org/obo/PO_0009049</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>inflorescence</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0008"></a>Term Name  acpart:p0008</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0008">http://rs.tdwg.org/acpart/values/p0008</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0008-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0008-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>fruit</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant structure developing from a flower</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0009001">http://purl.obolibrary.org/obo/PO_0009001</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>fruit</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0009"></a>Term Name  acpart:p0009</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0009">http://rs.tdwg.org/acpart/values/p0009</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0009-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0009-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>seed</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant structure containing dormant embryo</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0009010">http://purl.obolibrary.org/obo/PO_0009010</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>seed</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0010"></a>Term Name  acpart:p0010</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0010">http://rs.tdwg.org/acpart/values/p0010</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0010-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0010-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>male cone</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant strobilis bearing pollen</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0005031">http://purl.obolibrary.org/obo/PO_0005031</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>maleCone</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0006">acpart:p0006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0011"></a>Term Name  acpart:p0011</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0011">http://rs.tdwg.org/acpart/values/p0011</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0011-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0011-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>female cone</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant strobilis bearing ovules</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0005032">http://purl.obolibrary.org/obo/PO_0005032</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>femaleCone</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0006">acpart:p0006</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0012"></a>Term Name  acpart:p0012</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0012">http://rs.tdwg.org/acpart/values/p0012</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0012-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0012-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>flower</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Plant reproductive shoot system containing a carpel</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/PO_0009046">http://purl.obolibrary.org/obo/PO_0009046</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>flower</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0007">acpart:p0007</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0013"></a>Term Name  acpart:p0013</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0013">http://rs.tdwg.org/acpart/values/p0013</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0013-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0013-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>head</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Anterior-most division of the body</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0000033">http://purl.obolibrary.org/obo/UBERON_0000033</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>head</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0014"></a>Term Name  acpart:p0014</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0014">http://rs.tdwg.org/acpart/values/p0014</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0014-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0014-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>thorax</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The main middle section of the insect body</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_6000015">http://purl.obolibrary.org/obo/UBERON_6000015</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>thorax</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0015"></a>Term Name  acpart:p0015</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0015">http://rs.tdwg.org/acpart/values/p0015</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0015-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0015-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>abdomen</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The most posterior of the three tagma</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_6000020">http://purl.obolibrary.org/obo/UBERON_6000020</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>abdomen</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0016"></a>Term Name  acpart:p0016</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0016">http://rs.tdwg.org/acpart/values/p0016</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0016-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0016-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>leg</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Walking appendage</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0002101">http://purl.obolibrary.org/obo/UBERON_0002101</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>leg</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0017"></a>Term Name  acpart:p0017</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0017">http://rs.tdwg.org/acpart/values/p0017</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0017-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0017-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>wing</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Appendage that is shaped in order to produce lift for flight through the air</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0000023">http://purl.obolibrary.org/obo/UBERON_0000023</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>wing</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0018"></a>Term Name  acpart:p0018</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0018">http://rs.tdwg.org/acpart/values/p0018</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0018-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0018-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>antenna</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The paired, usually multiple jointed, sensory organs on the head</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0000972">http://purl.obolibrary.org/obo/UBERON_0000972</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>antenna</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0019"></a>Term Name  acpart:p0019</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0019">http://rs.tdwg.org/acpart/values/p0019</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0019-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0019-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>forewing</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The paired insect wing that is continuous with the mesonotum</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/AISM_0000037">http://purl.obolibrary.org/obo/AISM_0000037</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>forewing</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0017">acpart:p0017</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0020"></a>Term Name  acpart:p0020</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0020">http://rs.tdwg.org/acpart/values/p0020</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0020-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0020-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>hindwing</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The paired insect wing that is continuous with the metanotum</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/AISM_0000038">http://purl.obolibrary.org/obo/AISM_0000038</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>hindwing</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0017">acpart:p0017</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0021"></a>Term Name  acpart:p0021</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0021">http://rs.tdwg.org/acpart/values/p0021</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0021-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0021-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>foreleg</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Leg of the prothoracic segment</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_6004663">http://purl.obolibrary.org/obo/UBERON_6004663</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>foreleg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0016">acpart:p0016</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0022"></a>Term Name  acpart:p0022</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0022">http://rs.tdwg.org/acpart/values/p0022</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0022-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0022-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>midleg</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Leg of the mesothoracic segment</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/FBbt_00004685">http://purl.obolibrary.org/obo/FBbt_00004685</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>midleg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0016">acpart:p0016</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0023"></a>Term Name  acpart:p0023</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0023">http://rs.tdwg.org/acpart/values/p0023</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0023-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0023-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>hindleg</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Leg of the metathoracic segment</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/FBbt_00004707">http://purl.obolibrary.org/obo/FBbt_00004707</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>hindleg</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0016">acpart:p0016</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0024"></a>Term Name  acpart:p0024</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0024">http://rs.tdwg.org/acpart/values/p0024</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0024-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0024-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>eye</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>An organ that detects light</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0000970">http://purl.obolibrary.org/obo/UBERON_0000970</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>eye</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0025"></a>Term Name  acpart:p0025</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0025">http://rs.tdwg.org/acpart/values/p0025</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0025-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0025-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>shell</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>A rigid covering that envelops an object</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0006612">http://purl.obolibrary.org/obo/UBERON_0006612</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>shell</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0026"></a>Term Name  acpart:p0026</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0026">http://rs.tdwg.org/acpart/values/p0026</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0026-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0026-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>genitalia</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The outer sex organs</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0004176">http://purl.obolibrary.org/obo/UBERON_0004176</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>genitalia</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0027"></a>Term Name  acpart:p0027</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0027">http://rs.tdwg.org/acpart/values/p0027</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0027-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0027-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>skull</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The part of the head consisting entirely of cranium and mandible</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0003129">http://purl.obolibrary.org/obo/UBERON_0003129</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>skull</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0028"></a>Term Name  acpart:p0028</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0028">http://rs.tdwg.org/acpart/values/p0028</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0028-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0028-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>cranium</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Upper portion of the skull</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0003128">http://purl.obolibrary.org/obo/UBERON_0003128</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>cranium</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0027">acpart:p0027</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0029"></a>Term Name  acpart:p0029</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0029">http://rs.tdwg.org/acpart/values/p0029</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0029-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0029-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>mandible</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>A dentary bone that is the only bone in one of the lateral halves of the lower jaw</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0001684">http://purl.obolibrary.org/obo/UBERON_0001684</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>mandible</td>
		</tr>
		<tr>
			<td>Has broader concept</td>
			<td><a href="#acpart_p0027">acpart:p0027</a></td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0030"></a>Term Name  acpart:p0030</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0030">http://rs.tdwg.org/acpart/values/p0030</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0030-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0030-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>fin</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>An external projection of an aquatic animal used in propelling or guiding the body</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0008897">http://purl.obolibrary.org/obo/UBERON_0008897</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>fin</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0031"></a>Term Name  acpart:p0031</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0031">http://rs.tdwg.org/acpart/values/p0031</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-01-01</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0031-2022-01-01">http://rs.tdwg.org/acpart/values/version/p0031-2022-01-01</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>egg</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The hard-shelled reproductive body produced by a bird or a reptile</td>
		</tr>
		<tr>
			<td>Definition derived from:</td>
			<td><a href="http://purl.obolibrary.org/obo/UBERON_0007379">http://purl.obolibrary.org/obo/UBERON_0007379</a></td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>egg</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0032"></a>Term Name  acpart:p0032</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0032">http://rs.tdwg.org/acpart/values/p0032</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0032-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0032-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>archegoniophore</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>A specialized archegonial-bearing branch; the female gamentangiophore</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>archegoniophore</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0033"></a>Term Name  acpart:p0033</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0033">http://rs.tdwg.org/acpart/values/p0033</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0033-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0033-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>antheridiophore</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>A specialized antheridium-bearing branch; the male gamentangiophore</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>antheridiophore</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0034"></a>Term Name  acpart:p0034</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0034">http://rs.tdwg.org/acpart/values/p0034</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0034-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0034-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>antheridium</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Male gametangium; a multicellular globose to broadly cylindric, stalked structure containing spermatozoides</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>antheridium</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0035"></a>Term Name  acpart:p0035</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0035">http://rs.tdwg.org/acpart/values/p0035</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0035-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0035-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>archegonium</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Female gametangium; a multicellular, flask-shaped structure consisting of a stalk, venter, neck and containing an ovum</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>archegonium</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0036"></a>Term Name  acpart:p0036</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0036">http://rs.tdwg.org/acpart/values/p0036</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0036-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0036-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>gemma cup</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>Cup or moon-shaped, gemmae-containing structure of thalline or foliar origin</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>gemmaCup</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0037"></a>Term Name  acpart:p0037</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0037">http://rs.tdwg.org/acpart/values/p0037</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0037-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0037-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>thallus</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>A more of less flattened, gametophyte, not differentiated into a stem and leaves</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>thallus</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0038"></a>Term Name  acpart:p0038</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0038">http://rs.tdwg.org/acpart/values/p0038</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0038-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0038-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>sporophyte</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>The spore-bearing new generation; initiated by the fertilization of an egg; remaining attached to the gametophyte and partially dependent on it</td>
		</tr>
		<tr>
			<td>Notes</td>
			<td>Typically consisting of foot, seta, and capsule</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>sporophyte</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0039"></a>Term Name  acpart:p0039</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0039">http://rs.tdwg.org/acpart/values/p0039</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0039-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0039-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>sori</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>A cluster of spore-producing receptacles on the underside of a fern frond</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>sori</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>

<table>
	<thead>
		<tr>
			<th colspan="2"><a id="acpart_p0040"></a>Term Name  acpart:p0040</th>
		</tr>
	</thead>
	<tbody>
		<tr>
			<td>Term IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/p0040">http://rs.tdwg.org/acpart/values/p0040</a></td>
		</tr>
		<tr>
			<td>Modified</td>
			<td>2022-04-19</td>
		</tr>
		<tr>
			<td>Term version IRI</td>
			<td><a href="http://rs.tdwg.org/acpart/values/version/p0040-2022-04-19">http://rs.tdwg.org/acpart/values/version/p0040-2022-04-19</a></td>
		</tr>
		<tr>
			<td>Label</td>
			<td>rhizome</td>
		</tr>
		<tr>
			<td>Definition</td>
			<td>A modified subterranean stem that sends out roots and shoots from its nodes</td>
		</tr>
		<tr>
			<td>Controlled value</td>
			<td>rhizome</td>
		</tr>
		<tr>
			<td>Type</td>
			<td>Concept</td>
		</tr>
	</tbody>
</table>


